@@ -16,6 +16,7 @@ import botocore
 import botocore.stub
 import pytest
 from botocore.config import Config
+from botocore.httpchecksum import DEFAULT_CHECKSUM_ALGORITHM
 from botocore.stub import Stubber
 
 import boto3.session
@@ -86,7 +87,10 @@ class BaseTransferTest(unittest.TestCase):
             expected_params=expected_params,
         )
 
-    def stub_create_multipart_upload(self):
+    def stub_create_multipart_upload(
+        self,
+        extra_expected_params=None,
+    ):
         # Add the response and assert params for CreateMultipartUpload
         create_upload_response = {
             "Bucket": self.bucket,
@@ -97,13 +101,17 @@ class BaseTransferTest(unittest.TestCase):
             "Bucket": self.bucket,
             "Key": self.key,
         }
+        if extra_expected_params:
+            expected_params.update(extra_expected_params)
         self.stubber.add_response(
             method='create_multipart_upload',
             service_response=create_upload_response,
             expected_params=expected_params,
         )
 
-    def stub_complete_multipart_upload(self, parts):
+    def stub_complete_multipart_upload(
+        self, parts, extra_expected_params=None
+    ):
         complete_upload_response = {
             "Location": "us-west-2",
             "Bucket": self.bucket,
@@ -116,6 +124,8 @@ class BaseTransferTest(unittest.TestCase):
             "MultipartUpload": {"Parts": parts},
             "UploadId": self.upload_id,
         }
+        if extra_expected_params:
+            expected_params.update(extra_expected_params)
 
         self.stubber.add_response(
             method='complete_multipart_upload',
@@ -147,8 +157,8 @@ class TestCopy(BaseTransferTest):
         for i in range(num_parts):
             # Fill in the parts
             part_number = i + 1
-            copy_range = "bytes={}-{}".format(
-                i * part_size, i * part_size + (part_size - 1)
+            copy_range = (
+                f"bytes={i * part_size}-{i * part_size + (part_size - 1)}"
             )
             self.stub_copy_part(part_number=part_number, copy_range=copy_range)
             parts.append({'ETag': self.etag, 'PartNumber': part_number})
@@ -256,6 +266,7 @@ class TestUploadFileobj(BaseTransferTest):
             "Bucket": self.bucket,
             "Key": self.key,
             "Body": botocore.stub.ANY,
+            "ChecksumAlgorithm": DEFAULT_CHECKSUM_ALGORITHM,
         }
         self.stubber.add_response(
             method='put_object',
@@ -267,6 +278,7 @@ class TestUploadFileobj(BaseTransferTest):
         upload_part_response = {
             'ETag': self.etag,
             'ResponseMetadata': {'HTTPStatusCode': 200},
+            'ChecksumCRC32': f'sum{part_number}==',
         }
         expected_params = {
             "Bucket": self.bucket,
@@ -274,6 +286,7 @@ class TestUploadFileobj(BaseTransferTest):
             "Body": botocore.stub.ANY,
             "PartNumber": part_number,
             "UploadId": self.upload_id,
+            'ChecksumAlgorithm': 'CRC32',
         }
         self.stubber.add_response(
             method='upload_part',
@@ -282,7 +295,11 @@ class TestUploadFileobj(BaseTransferTest):
         )
 
     def stub_multipart_upload(self, num_parts):
-        self.stub_create_multipart_upload()
+        self.stub_create_multipart_upload(
+            extra_expected_params={
+                "ChecksumAlgorithm": DEFAULT_CHECKSUM_ALGORITHM,
+            }
+        )
 
         # Add the responses for each UploadPartCopy
         parts = []
@@ -290,7 +307,13 @@ class TestUploadFileobj(BaseTransferTest):
             # Fill in the parts
             part_number = i + 1
             self.stub_upload_part(part_number=part_number)
-            parts.append({'ETag': self.etag, 'PartNumber': part_number})
+            parts.append(
+                {
+                    'ETag': self.etag,
+                    'PartNumber': part_number,
+                    'ChecksumCRC32': f'sum{part_number}==',
+                }
+            )
 
         self.stub_complete_multipart_upload(parts)
 
@@ -389,8 +412,8 @@ class TestDownloadFileobj(BaseTransferTest):
         if end_byte is not None:
             contents = full_contents[start_byte : end_byte + 1]
             part_range = f'bytes={start_byte}-{end_byte_range}'
-            content_range = 'bytes={}-{}/{}'.format(
-                start_byte, end_byte, len(full_contents)
+            content_range = (
+                f'bytes={start_byte}-{end_byte}/{len(full_contents)}'
             )
             get_object_response['ContentRange'] = content_range
             expected_params['Range'] = part_range
