@@ -274,7 +274,7 @@ class TestResourceDocstrings(BaseDocsTest):
                     ':py:meth:`MyService.Waiter.sample_operation_complete.wait` '
                     'which polls :py:meth:`MyService.Client.sample_operation` every '
                     '15 seconds until a successful state is reached. An error '
-                    'is returned after 40 failed checks.'
+                    'is raised after 40 failed checks.'
                 ),
                 '    **Request Syntax**',
                 '    ::',
